<?php
/**
 * WCFM Vendor Membership plugin core
 *
 * Plugin Frontend Controler
 *
 * @author 		WC Lovers
 * @package 	wcfmvm/core
 * @version   1.0.0
 */
 
class WCFMvm_Frontend {
	
	public function __construct() {
		global $WCFM, $WCFMvm;
		
		// WCFM Membership Page Template
 		add_action( 'page_template', array( &$this, 'wcfm_membership_template' ) );
		
		// WCFM Membership End Points
		add_filter( 'wcfm_query_vars', array( &$this, 'wcfmvm_vendor_membership_wcfm_query_vars' ), 90 );
		add_filter( 'wcfm_endpoint_title', array( &$this, 'wcfmvm_vendor_membership_endpoint_title' ), 90, 2 );
		add_action( 'init', array( &$this, 'wcfmvm_vendor_membership_init' ), 90 );
		
		// WCFM Membership Page
		add_filter( 'wcfm_settings_fields_pages', array( $this, 'wcfmvm_settings_fields_pages' ) ); 
		
		// WCFM Membership Endpoint Edit
		add_filter( 'wcfm_endpoints_slug', array( $this, 'wcfmvm_vendor_membership_endpoints_slug' ) );
		
		// WCFM Menu Filter
		add_filter( 'wcfm_menus', array( &$this, 'wcfmvm_vendor_membership_menus' ), 300 );
		add_filter( 'wcfm_menu_dependancy_map', array( &$this, 'wcfmvm_vendor_membership_menu_dependancy_map' ) );
		
		// Membership Details in Profile 
		if( wcfm_is_vendor() ) {
			add_filter( 'wcfm_dashboard_username', array( &$this, 'wcfmvm_vendor_dashboard_username' ), 12 );
			add_action( 'end_wcfm_user_profile', array( &$this, 'wcfmvm_vendor_membership_user_profile' ), 12 );
		}
		
		// Membership direct message type
		add_filter( 'wcfm_message_types', array( &$this, 'wcfm_membership_message_types' ) );
		
		// Membership enqueue scripts
		add_action('wp_enqueue_scripts', array(&$this, 'wcfmvm_scripts'));
		// Membership enqueue styles
		add_action('wp_enqueue_scripts', array(&$this, 'wcfmvm_styles'));
		
	}
	
	/**
 	 * WCFM Page template if full screen selected
 	 */
	function wcfm_membership_template( $page_template ) {
		global $WCFM;
		if ( wc_post_content_has_shortcode( 'wcfm_vendor_membership' ) ) {
			$wcfm_options = get_option('wcfm_options');
			$is_dashboard_full_view_disabled = isset( $wcfm_options['dashboard_full_view_disabled'] ) ? $wcfm_options['dashboard_full_view_disabled'] : 'no';
			$is_dashboard_theme_header_disabled = isset( $wcfm_options['dashboard_theme_header_disabled'] ) ? $wcfm_options['dashboard_theme_header_disabled'] : 'no';
			if( $is_dashboard_full_view_disabled != 'yes' ) {
				$template_path = WC()->template_path();
				$skin_path     = $WCFM->plugin_path . 'templates/classic/';
				if( $is_dashboard_theme_header_disabled == 'yes' ) $skin_path     = $WCFM->plugin_path . 'templates/default/';
				$page_template = wc_locate_template( 'wcfm-content.php', $template_path, $skin_path );
			}
		}

		return $page_template;
	}
	
	/**
   * WCFM Membership Query Var
   */
  function wcfmvm_vendor_membership_wcfm_query_vars( $query_vars ) {
  	$wcfm_modified_endpoints = (array) get_option( 'wcfm_endpoints' );
  	
		$query_vendor_membership_vars = array(
			'wcfm-memberships'          => ! empty( $wcfm_modified_endpoints['wcfm-memberships'] ) ? $wcfm_modified_endpoints['wcfm-memberships'] : 'wcfm-memberships',
			'wcfm-memberships-manage'    => ! empty( $wcfm_modified_endpoints['wcfm-memberships-manage'] ) ? $wcfm_modified_endpoints['wcfm-memberships-manage'] : 'wcfm-memberships-manage',
			'wcfm-memberships-settings'  => ! empty( $wcfm_modified_endpoints['wcfm-memberships-settings'] ) ? $wcfm_modified_endpoints['wcfm-memberships-settings'] : 'wcfm-memberships-settings',
		);
		
		$query_vars = array_merge( $query_vars, $query_vendor_membership_vars );
		
		return $query_vars;
  }
  
  /**
   * WCFM Membership End Point Title
   */
  function wcfmvm_vendor_membership_endpoint_title( $title, $endpoint ) {
  	
  	switch ( $endpoint ) {
			case 'wcfm-memberships' :
				$title = __( 'Memberships', 'wc-frontend-manager-vendor-membership' );
			break;
			case 'wcfm-memberships-manage' :
				$title = __( 'Membership Manage', 'wc-frontend-manager-vendor-membership' );
			break;
			case 'wcfm-memberships-settings' :
				$title = __( 'Membership Settings', 'wc-frontend-manager-vendor-membership' );
			break;
  	}
  	
  	return $title;
  }
  
  /**
   * WCFM Membership Endpoint Intialize
   */
  function wcfmvm_vendor_membership_init() {
  	global $WCFM_Query;
	
		// Intialize WCFM End points
		$WCFM_Query->init_query_vars();
		$WCFM_Query->add_endpoints();
		
		if( !get_option( 'wcfm_updated_end_point_wcfmvm_vendor_membership' ) ) {
			// Flush rules after endpoint update
			flush_rewrite_rules();
			update_option( 'wcfm_updated_end_point_wcfmvm_vendor_membership', 1 );
		}
  }
  
  /**
	 * WCFM Membership Pages Edit
	 */
  function wcfmvm_settings_fields_pages( $wcfm_pages ) {
  	$wcfm_page_options = get_option( 'wcfm_page_options', array() );
  	$wcfm_pages["wcfm_vendor_membership_page_id"] = array( 'label' => __('Membership', 'wc-frontend-manager-vendor-membership'), 'type' => 'select', 'name' => 'wcfm_page_options[wcfm_vendor_membership_page_id]', 'options' => $wcfm_pages["wc_frontend_manager_page_id"]['options'], 'class' => 'wcfm-select wcfm_ele', 'label_class' => 'wcfm_title', 'value' => isset($wcfm_page_options['wcfm_vendor_membership_page_id']) ? $wcfm_page_options['wcfm_vendor_membership_page_id'] : '', 'desc_class' => 'wcfm_page_options_desc', 'desc' => __( 'This page should have shortcode - wcfm_vendor_membership', 'wc-frontend-manager') );
  	
  	return $wcfm_pages;
  }
  
  /**
	 * WCFM Membership Endpoiint Edit
	 */
	function wcfmvm_vendor_membership_endpoints_slug( $endpoints ) {
		
		$wcfmvm_vendor_membership_endpoints = array(
													'wcfm-memberships'            => 'wcfm-memberships',
													'wcfm-memberships-manage'     => 'wcfm-memberships-manage',
													'wcfm-memberships-settings'   => 'wcfm-memberships-settings',
													);
		
		$endpoints = array_merge( $endpoints, $wcfmvm_vendor_membership_endpoints );
		
		return $endpoints;
	}
  
  /**
   * WCFM Membership Menu
   */
  function wcfmvm_vendor_membership_menus( $menus ) {
  	global $WCFM;
  	
		if( !apply_filters( 'wcfm_is_allow_membership', true ) ) return $menus;
		
		$menus = array_slice($menus, 0, 3, true) +
										array( 'wcfm-memberships' => array(   'label'     => __( 'Memberships', 'wc-frontend-manager-vendor-membership'),
																												 'url'        => get_wcfm_memberships_url( ),
																												 'icon'       => 'user-plus',
																												 'priority'   => 62
																												) )	 +
													array_slice($menus, 3, count($menus) - 3, true) ;
		
  	return $menus;
  }
  
  /**
   * WCFM Membership Menu Dependency
   */
  function wcfmvm_vendor_membership_menu_dependancy_map( $menu_dependency_mapping ) {
  	$menu_dependency_mapping['wcfm-memberships-manage'] = 'wcfm-memberships';
  	$menu_dependency_mapping['wcfm-memberships-settings'] = 'wcfm-memberships';
  	return $menu_dependency_mapping;
  }
  
  function wcfmvm_vendor_dashboard_username( $username ) {
  	global $WCFM, $WCFMvm;
		
		$vendor_id   = apply_filters( 'wcfm_current_vendor_id', get_current_user_id() );
		$wcfm_membership_id = get_user_meta( $vendor_id, 'wcfm_membership', true );
		if( $wcfm_membership_id ) {
			$membership_post = get_post( $wcfm_membership_id );
			$title = htmlspecialchars($membership_post->post_title);
			
			$username .= ' <span class="wcfm_dashboard_membership_details">(' . $title . ' ' . __( 'Membership', 'wc-frontend-manager-vendor-membership' ) . ')</span>'; 
		}
		return $username;
  }
  
  function wcfmvm_vendor_membership_user_profile() {
		global $WCFM, $WCFMvm;
		
		$vendor_id   = apply_filters( 'wcfm_current_vendor_id', get_current_user_id() );
		$wcfm_membership_id = get_user_meta( $vendor_id, 'wcfm_membership', true );
		
		?>
		<div class="page_collapsible profile_manage_membership" id="wcfm_profile_manage_form_membership_head"><label class="fa fa-user-plus"></label><?php _e( 'Membership', 'wc-frontend-manager-vendor-membership' ); ?><span></span></div>
		<div class="wcfm-container">
			<div id="wcfm_profile_manage_form_membership_expander" class="wcfm-content">
			  <?php
			  if( $wcfm_membership_id ) {
			  	$membership_post = get_post( $wcfm_membership_id );
					$title = htmlspecialchars($membership_post->post_title);
					$description = htmlspecialchars($membership_post->post_excerpt);
 		
			  	$subscription = (array) get_post_meta( $wcfm_membership_id, 'subscription', true );
					$features = (array) get_post_meta( $wcfm_membership_id, 'features', true );
					
					$is_free = isset( $subscription['is_free'] ) ? 'yes' : 'no';
					$subscription_type = isset( $subscription['subscription_type'] ) ? $subscription['subscription_type'] : 'one_time';
					$one_time_amt = isset( $subscription['one_time_amt'] ) ? $subscription['one_time_amt'] : '1';
					$trial_amt = isset( $subscription['trial_amt'] ) ? $subscription['trial_amt'] : '';
					$trial_period = isset( $subscription['trial_period'] ) ? $subscription['trial_period'] : '';
					$trial_period_type = isset( $subscription['trial_period_type'] ) ? $subscription['trial_period_type'] : 'M';
					$billing_amt = isset( $subscription['billing_amt'] ) ? $subscription['billing_amt'] : '1';
					$billing_period = isset( $subscription['billing_period'] ) ? $subscription['billing_period'] : '1';
					$billing_period_type = isset( $subscription['billing_period_type'] ) ? $subscription['billing_period_type'] : 'M';
					$period_options = array( 'D' => __( 'Day(s)', 'wc-frontend-manager-vendor-membership' ), 'M' => __( 'Month(s)', 'wc-frontend-manager-vendor-membership' ), 'Y' => __( 'Year(s)', 'wc-frontend-manager-vendor-membership' ) );
					
					if( $is_free == 'yes' ) {
						echo "<h2>";
						printf( __( 'You have neen subscribed for %s membership!', 'wc-frontend-manager-vendor-membership' ), $title );
						echo "</h2><div class=\"wcfm_clearfix\"></div><br />";
						if( $description ) echo $description . "<br /><br />";
					} else {
						if( $subscription_type == 'one_time' ) {
							echo "<h2>";
							printf( __( 'You have neen subscribed for %s membership!', 'wc-frontend-manager-vendor-membership' ), $title );
							echo "</h2><div class=\"wcfm_clearfix\"></div><br />";
							if( $description ) echo $description . "<br /><br />";
							_e( 'Plan Details: ', 'wc-frontend-manager-vendor-membership' );
							echo wc_price($one_time_amt);
							echo ' <span class="wcfm_membership_price_description">(' . __( 'One time payment', 'wc-frontend-manager-vendor-membership' ) . ')</span>';
						} else {
							echo "<h2>";
							printf( __( 'You have neen subscribed for %s membership!', 'wc-frontend-manager-vendor-membership' ), $title );
							echo "</h2><div class=\"wcfm_clearfix\"></div><br />";
							if( $description ) echo $description . "<br /><br />";
							_e( 'Plan Details: ', 'wc-frontend-manager-vendor-membership' );
							echo wc_price($billing_amt);
							$price_description = sprintf( __( 'for each %s %s', 'wc-frontend-manager-vendor-membership' ), $billing_period, $period_options[$billing_period_type] );
							if( !empty( $trial_period ) && !empty( $trial_amt ) ) {
								$price_description .= ' ' . sprintf( __( 'with %s for first %s %s', 'wc-frontend-manager-vendor-membership' ), get_woocommerce_currency_symbol() . $trial_amt, $trial_period, $period_options[$trial_period_type] );
							}
							echo ' <span class="wcfm_membership_price_description">(' . $price_description . ')</span>';
						}
					}
			  } else {
			  	echo "<h2>";
			  	_e( 'You are not subscribed for a membership yet!', 'wc-frontend-manager-vendor-membership' );
			  	echo "</h2><div class=\"wcfm_clearfix\"></div><br />";
			  }
			  ?>
			</div>
		</div>
		<?php
	}
  
  function wcfm_membership_message_types( $message_types ) {
		$message_types['membership'] = __( 'Membership', 'wc-frontend-manager-vendor-membership' );
		return $message_types;
	}
  
  /**
	 * WCFMvm Core JS
	 */
	function wcfmvm_scripts() {
 		global $WCFMvm, $wp, $WCFM_Query;
 		
 		if( isset( $_REQUEST['fl_builder'] ) ) return;
 		
 		// Load End Point Scripts
	  if( is_wcfm_membership_page() ) {
	  	$current_step = wcfm_membership_registration_current_step();
			
			switch( $current_step ) {
				case 'registration':
					wp_enqueue_script( 'wcfm_membership_registration_js', $WCFMvm->library->js_lib_url . 'wcfmvm-script-membership-registration.js', array('jquery' ), $WCFMvm->version, true );
				break;
				
				case 'payment':
					wp_enqueue_script( 'wcfm_membership_payment_js', $WCFMvm->library->js_lib_url . 'wcfmvm-script-membership-payment.js', array('jquery' ), $WCFMvm->version, true );
				break;
				
				default:
					wp_enqueue_script( 'wcfm_membership_js', $WCFMvm->library->js_lib_url . 'wcfmvm-script-membership-display.js', array('jquery' ), $WCFMvm->version, true );
				break;
			}
	  }
 	}
 	
 	/**
 	 * WCFMvm Core CSS
 	 */
 	function wcfmvm_styles() {
 		global $WCFMvm, $wp, $WCFM_Query;
 		
 		if( isset( $_REQUEST['fl_builder'] ) ) return;
 		
 		// Load End Point Scripts
	  if( is_wcfm_membership_page() ) {
	  	$current_step = wcfm_membership_registration_current_step();
			
			wp_enqueue_style( 'wcfm_membership_steps_css',  $WCFMvm->library->css_lib_url . 'wcfmvm-style-membership-steps.css', array(), $WCFMvm->version );
			
			switch( $current_step ) {
				case 'registration':
					wp_enqueue_style( 'wcfm_membership_registration_css',  $WCFMvm->library->css_lib_url . 'wcfmvm-style-membership-registration.css', array(), $WCFMvm->version );
				break;
				
				case 'payment':
					wp_enqueue_style( 'wcfm_membership_payment_css',  $WCFMvm->library->css_lib_url . 'wcfmvm-style-membership-payment.css', array(), $WCFMvm->version );
				break;
				
				case 'thankyou':
					wp_enqueue_style( 'wcfm_membership_thankyou_css',  $WCFMvm->library->css_lib_url . 'wcfmvm-style-membership-thankyou.css', array(), $WCFMvm->version );
				break;
				
				default:
					wp_enqueue_style( 'wcfm_membership_css',  $WCFMvm->library->css_lib_url . 'wcfmvm-style-membership-display.css', array(), $WCFMvm->version );
				break;
			}
			
			// WCFMvm Custom CSS
			$upload_dir      = wp_upload_dir();
			$wcfmvm_style_custom = get_option( 'wcfmvm_style_custom' );
			if( file_exists( trailingslashit( $upload_dir['basedir'] ) . 'wcfm/' . $wcfmvm_style_custom ) ) {
				wp_enqueue_style( 'wcfmvm_custom_css',  trailingslashit( $upload_dir['baseurl'] ) . 'wcfm/' . $wcfmvm_style_custom, array( 'wcfm_membership_steps_css' ), $WCFMvm->version );
			}
	  }
 	}
 	
 	/**
 	 * PayPal request form
 	 */
 	function generate_paypal_request_form( $membership_id, $member_id ) {
 		global $WCFM, $WCFMvm;
 		
 		$membership_post = get_post( $membership_id );
 		$title = htmlspecialchars($membership_post->post_title);
 		$description = htmlspecialchars($membership_post->post_excerpt);
 		
 		$wcfm_membership_options = get_option( 'wcfm_membership_options', array() );
 		$membership_payment_settings = array();
		if( isset( $wcfm_membership_options['membership_payment_settings'] ) ) $membership_payment_settings = $wcfm_membership_options['membership_payment_settings'];
		$paypal_email = ( $membership_payment_settings['paypal_email'] ) ? $membership_payment_settings['paypal_email'] : '';
		$paypal_sandbox = isset( $membership_payment_settings['paypal_sandbox'] ) ? 'yes' : 'no';
 		
 		$subscription = (array) get_post_meta( $membership_id, 'subscription', true );
 		$subscription_type = isset( $subscription['subscription_type'] ) ? $subscription['subscription_type'] : 'one_time';
		$one_time_amt = isset( $subscription['one_time_amt'] ) ? $subscription['one_time_amt'] : '1';
		$trial_amt = isset( $subscription['trial_amt'] ) ? $subscription['trial_amt'] : '';
		$trial_period = isset( $subscription['trial_period'] ) ? $subscription['trial_period'] : '';
		$trial_period_type = isset( $subscription['trial_period_type'] ) ? $subscription['trial_period_type'] : 'M';
		$billing_amt = isset( $subscription['billing_amt'] ) ? $subscription['billing_amt'] : '1';
		$billing_period = isset( $subscription['billing_period'] ) ? $subscription['billing_period'] : '1';
		$billing_period_type = isset( $subscription['billing_period_type'] ) ? $subscription['billing_period_type'] : 'M';
		$billing_period_count = isset( $subscription['billing_period_count'] ) ? $subscription['billing_period_count'] : 1;
		$re_attempt = isset( $subscription['re_attempt'] ) ? 'yes' : 'no';
		
		?>
		<form action="https://www<?php if( $paypal_sandbox == 'yes' ) echo '.sandbox'; ?>.paypal.com/cgi-bin/webscr" method="post">
		  <?php if( $subscription_type == 'one_time' ) { ?>
		  	<input type="hidden" name="cmd" value="_xclick">
		  <?php } else { ?>
		  	<input type="hidden" name="cmd" value="_xclick-subscriptions">
		  <?php } ?>
			<input type="hidden" name="charset" value="utf-8">
			<input type="hidden" name="bn" value="TipsandTricks_SP">
			<input type="hidden" name="business" value="<?php echo $paypal_email; ?>">
			<input type="hidden" name="currency_code" value="<?php echo get_woocommerce_currency(); ?>">
			<input type="hidden" name="item_number" value="<?php echo $membership_id; ?>">
			<input type="hidden" name="item_name" value="<?php echo $title . ' - ' . $description; ?>">
			
			<?php if( $subscription_type == 'one_time' ) { ?>
		  	<input type="hidden" name="amount" value="<?php echo $one_time_amt; ?>" />
		  <?php } else { ?>
				<?php if( !empty( $trial_period ) && !empty( $trial_amt ) ) { ?>
					<input type="hidden" name="a1" value="<?php echo $trial_amt; ?>">
					<input type="hidden" name="p1" value="<?php echo $trial_period; ?>">
					<input type="hidden" name="t1" value="<?php echo $trial_period_type; ?>">
				<?php } ?>
				
				<?php if( !empty( $billing_period ) && !empty( $billing_amt ) ) { ?>
					<input type="hidden" name="a3" value="<?php echo $billing_amt; ?>">
					<input type="hidden" name="p3" value="<?php echo $billing_period; ?>">
					<input type="hidden" name="t3" value="<?php echo $billing_period_type; ?>">
				<?php } ?>
				
				<?php if( $re_attempt == 'yes' ) { ?>
					<input type="hidden" name="sra" value="1">
				<?php } ?>
				
				<?php if ( $billing_period_count > 1 ) { ?>
					<input type="hidden" name="src" value="1" />
					<input type="hidden" name="srt" value="<?php echo $billing_period_count; ?>" />
				<?php } else if ( empty( $billing_period_count ) ) { ?>
					<input type="hidden" name="src" value="1" />
				<?php } ?>
			<?php } ?>
	
			<input type="hidden" name="no_shipping" value="1">
			<input type="hidden" name="notify_url" value="<?php echo add_query_arg( 'wcfmvm_process_ipn', 'paypal_ipn', get_wcfm_membership_url() ); ?>">
			<input type="hidden" name="return" value="<?php echo add_query_arg( 'vmstep', 'thankyou', get_wcfm_membership_url() ); ?>">
			<input type="hidden" name="cancel_return" value="<?php echo add_query_arg( 'vmstep', 'cancel', get_wcfm_membership_url() ); ?>">
			<input type="hidden" name="custom" value="<?php echo $member_id; ?>">
		<?php
 	}
}